##  3. Can I configure more than one Portal?
Yes, if you are an admin user. The system supports more than one portal when settings are defined by an Admin user. Every portal can have different settings and different Fact Sheet types.
